==> com.liferay.dynamic.data.mapping.service-3.0.151-sources.jar: com/liferay/dynamic/data/mapping/model/impl/DDMFormInstanceRecordImpl.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.dynamic.data.mapping.model.impl;

import com.liferay.dynamic.data.mapping.model.DDMFormInstance;
import com.liferay.dynamic.data.mapping.model.DDMFormInstanceRecordVersion;
import com.liferay.dynamic.data.mapping.service.DDMFormInstanceLocalServiceUtil;
import com.liferay.dynamic.data.mapping.service.DDMFormInstanceRecordLocalServiceUtil;
import com.liferay.dynamic.data.mapping.service.DDMFormInstanceRecordVersionLocalServiceUtil;
import com.liferay.dynamic.data.mapping.storage.DDMFormValues;
import com.liferay.portal.kernel.exception.PortalException;

/**
 * @author Brian Wing Shun Chan
 */
public class DDMFormInstanceRecordImpl extends DDMFormInstanceRecordBaseImpl {

	@Override
	public DDMFormValues getDDMFormValues() throws PortalException {
		return DDMFormInstanceRecordLocalServiceUtil.getDDMFormValues(
			getStorageId());
	}

	@Override
	public DDMFormInstance getFormInstance() throws PortalException {
		return DDMFormInstanceLocalServiceUtil.getFormInstance(
			getFormInstanceId());
	}

	@Override
	public DDMFormInstanceRecordVersion getFormInstanceRecordVersion()
		throws PortalException {

		return getFormInstanceRecordVersion(getVersion());
	}

	@Override
	public DDMFormInstanceRecordVersion getFormInstanceRecordVersion(
			String version)
		throws PortalException {

		return DDMFormInstanceRecordVersionLocalServiceUtil.
			getFormInstanceRecordVersion(getFormInstanceRecordId(), version);
	}

	@Override
	public DDMFormInstanceRecordVersion getLatestFormInstanceRecordVersion()
		throws PortalException {

		return DDMFormInstanceRecordVersionLocalServiceUtil.
			getLatestFormInstanceRecordVersion(getFormInstanceRecordId());
	}

	@Override
	public int getStatus() throws PortalException {
		DDMFormInstanceRecordVersion ddmFormInstanceRecordVersion =
			getFormInstanceRecordVersion();

		return ddmFormInstanceRecordVersion.getStatus();
	}

}

==> com.liferay.dynamic.data.mapping.service-4.0.17-sources.jar: com/liferay/dynamic/data/mapping/model/impl/DDMFormInstanceRecordImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.dynamic.data.mapping.model.impl;

import com.liferay.dynamic.data.mapping.model.DDMFormInstance;
import com.liferay.dynamic.data.mapping.model.DDMFormInstanceRecordVersion;
import com.liferay.dynamic.data.mapping.service.DDMFormInstanceLocalServiceUtil;
import com.liferay.dynamic.data.mapping.service.DDMFormInstanceRecordVersionLocalServiceUtil;
import com.liferay.dynamic.data.mapping.storage.DDMFormValues;
import com.liferay.portal.kernel.exception.PortalException;

import org.osgi.annotation.versioning.ProviderType;

/**
 * @author Brian Wing Shun Chan
 */
@ProviderType
public class DDMFormInstanceRecordImpl extends DDMFormInstanceRecordBaseImpl {

	@Override
	public DDMFormValues getDDMFormValues() throws PortalException {
		DDMFormInstanceRecordVersion latestFormInstanceRecordVersion =
			getLatestFormInstanceRecordVersion();

		return latestFormInstanceRecordVersion.getDDMFormValues();
	}

	@Override
	public DDMFormInstance getFormInstance() throws PortalException {
		return DDMFormInstanceLocalServiceUtil.getFormInstance(
			getFormInstanceId());
	}

	@Override
	public DDMFormInstanceRecordVersion getFormInstanceRecordVersion()
		throws PortalException {

		return getFormInstanceRecordVersion(getVersion());
	}

	@Override
	public DDMFormInstanceRecordVersion getFormInstanceRecordVersion(
			String version)
		throws PortalException {

		return DDMFormInstanceRecordVersionLocalServiceUtil.
			getFormInstanceRecordVersion(getFormInstanceRecordId(), version);
	}

	@Override
	public DDMFormInstanceRecordVersion getLatestFormInstanceRecordVersion()
		throws PortalException {

		return DDMFormInstanceRecordVersionLocalServiceUtil.
			getLatestFormInstanceRecordVersion(getFormInstanceRecordId());
	}

	@Override
	public int getStatus() throws PortalException {
		DDMFormInstanceRecordVersion ddmFormInstanceRecordVersion =
			getFormInstanceRecordVersion();

		return ddmFormInstanceRecordVersion.getStatus();
	}

}
